
% ============================================================
% Script that computes pressure input to 2D OpenFOAM model 
% from Stokes fifth order wave theory by Skjelbreia and 
% Hendrickson (1960) for n strips at n+1 planes
% ============================================================
% Master's thesis: Modelling of Ringing Loads on Offshore Wind
% Turbine monopiles
% Department of Marine Technology, NTNU
% Spring 2020
% ============================================================
% Modified: Vilde Mathisen, 20.05.20
% ============================================================

clear all


ha = 7.83;
ka = 0.388;
steep_1 = 0.04;
steep = 1/steep_1;

if ka == 0.105
    Tper = 2.021;
elseif ka == 0.127
    Tper = 1.732;
elseif ka == 0.163
    Tper = 1.443;
elseif ka == 0.388
    Tper = 0.866;
elseif ka == 0.290
    Tper = 1.010;
elseif ka == 0.229
    Tper = 1.155;
elseif ka == 0.190
    Tper = 1.299;
elseif ka == 0.142
    Tper = 1.588;
elseif ka == 0.115
    Tper = 1.876;
elseif ka ==0.097
    Tper = 2.165;
elseif ka == 0.090
    Tper = 2.309;
else 
    disp('Invalid ka number');
end

scale = 48;
d = 6.9/scale;
aa = d/2;
a = aa;
h = ha*aa;
rho = 1000;
g = 9.81;
Nper = 8;
LL = 20*d;

pth0 = 'Stokes_waves/';
pth1     = pth0;   % studydir meshdir]

%% Stokes fifth order waves
[k dudtt dudzz zeta time zv]  = stokes5thWaves(h,Tper,steep,Nper);

%% Dicretization of cylinder    
m = 10; 
dz = meshStretch(zv,max(zeta),h,m);

%Strip coordinates
z_plane(1) = -h;
[dudt_plane(1,:) dudz_plane(1,:) k u] = stokes5thWaves_planeValue(h,Tper,steep,Nper,z_plane(1),time);
pin_plane(1,:) = 0.5*LL*dudt_plane(1,:);
pout_plane(1,:) = -pin_plane(1,:);

    kcdir = ['ha' num2str(h/aa,'%1.2f') '/ka' num2str(ka,'%1.3f') '/steep' num2str(1/steep,'%1.3f') '/plane' num2str(0,'%i') '/']
    pth = [pth1 kcdir];
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(pth1,kcdir);
    
    filename = [pth 'z.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n',['  ' num2str(z_plane(1)) ' ']);
    fclose(fid);
   
    filename = [pth 'pin.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n','(');
    for it = 1:length(time)
      fprintf(fid,'%s \n',['(  ' num2str(time(it)) '  ' num2str(pin_plane(1,it))  '  )']);
    end
    fprintf(fid,'%s',')');
    fclose(fid);
    
        filename = [pth 'pout.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n','(');
    for it = 1:length(time)
      fprintf(fid,'%s \n',['(  ' num2str(time(it)) '  ' num2str(pout_plane(1,it))  '  )']);
    end
    fprintf(fid,'%s',')');
    fclose(fid);
   
   %% Copy the directories 0, constant and system:
    filenamevec = {'0' 'constant' 'system'};
    nfiles = length(filenamevec);
    for ifile = 1:nfiles
      fname = char(filenamevec{ifile});
      filename1 = [pth1 fname];
      filename2 = [pth  fname];
      
      %if ((filename2(end) ~= 't'))
        [SUCCESS,MESSAGE,MESSAGEID] = copyfile(filename1 ,filename2);
      %end
    end
 

% Pressure on plane
for i = 2:m+1
    z_plane(i) = sum(dz(1:i)) - h;
    [dudt_plane(i,:) dudz_plane(i,:) k u(i,:)] = stokes5thWaves_planeValue(h,Tper,steep,Nper,z_plane(i),time);
    pin_plane(i,:) = 0.5*LL*dudt_plane(i,:);
    pout_plane(i,:) = -pin_plane(i,:);
    
    %Write to input files for plane 1,2..m

    %% Create directory:    

    kcdir = ['ha' num2str(h/aa,'%1.2f') '/ka' num2str(ka,'%1.3f') '/steep' num2str(1/steep,'%1.3f') '/plane' num2str(i-1,'%i') '/']
    pth = [pth1 kcdir];
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(pth1,kcdir);
    
    filename = [pth 'z.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n',['  ' num2str(z_plane(i)) ' ']);
    fclose(fid);
   
    filename = [pth 'pin.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n','(');
    for it = 1:length(time)
      fprintf(fid,'%s \n',['(  ' num2str(time(it)) '  ' num2str(pin_plane(i,it))  '  )']);
    end
    fprintf(fid,'%s',')');
    fclose(fid);
    
        filename = [pth 'pout.txt'];
    fid = fopen(filename,'w');
    fprintf(fid,'%s \n','(');
    for it = 1:length(time)
      fprintf(fid,'%s \n',['(  ' num2str(time(it)) '  ' num2str(pout_plane(i,it))  '  )']);
    end
    fprintf(fid,'%s',')');
    fclose(fid);
   
   %% Copy the directories 0, constant and system:
    filenamevec = {'0' 'constant' 'system'};
    nfiles = length(filenamevec);
    for ifile = 1:nfiles
      fname = char(filenamevec{ifile});
      filename1 = [pth1 fname];
      filename2 = [pth  fname];
      
      %if ((filename2(end) ~= 't'))
        [SUCCESS,MESSAGE,MESSAGEID] = copyfile(filename1 ,filename2);
      %end
    end
    

end

%for i = 1:m+1
    KC = max(u(11,:))*Tper/d
%end

% clf
% 
% a(1:m+1) = a;
% a_2 = -a;
% z1 = 0;
% x1 = -h/2;
% x2 = h/2
% z2 = 0;
% 
% for i = 1:m
%     plot([a(i) a(i+1)], [z_plane(i) z_plane(i+1)],'Color',[0 0 0])
%     hold on
%     plot([a_2(i) a_2(i+1)], [z_plane(i) z_plane(i+1)],'Color',[0 0 0])
%     plot([a(i) a_2(i)], [z_plane(i) z_plane(i)],'Color',[0 0 0])
%     plot([a(m+1) a_2(m+1)], [z_plane(m+1) z_plane(m+1)],'Color',[0 0 0])
% end
% 
%     for i = 1:m
%         plot([a(i) a(i+1)], [z_plane(i) z_plane(i+1)],'Color',[0 0 0])
%         hold on
%     end
%     plot([x1 x2], [z1 z2],'--','Color',[0 0 0])
%     
% plot(-time/2,zeta,'b','LineWidth',2);
% hold on
% plot(time/2,zeta,'b','Linewidth',2);
% ylabel('$z$','Interpreter','latex','FontSize',26);
% xlabel('$x$','Interpreter','latex','FontSize',26);
% title('$ka = 0.105$, $H/\lambda = 1/25$','Interpreter','latex','FontSize',23);
% xlim([-h/2 h/2])
% ylim([-h h/2])

